This is the mail archive of the gdb-patches@sources.redhat.com mailing list for the GDB project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] s/Linux/.../ done


Last one (I hope).
2002-02-24  Andrew Cagney  <ac131313@redhat.com>

	* config/nm-linux.h, config/alpha/nm-linux.h: Ditto.
	* config/alpha/tm-alpha.h, config/alpha/tm-alphalinux.h:
	* config/alpha/xm-alphalinux.h, config/i386/nm-linux.h: Ditto.
	* config/i386/nm-x86-64.h, config/i386/tm-linux.h: Ditto.
	* config/m68k/tm-linux.h, config/mips/nm-linux.h: Ditto.
	* config/mips/tm-linux.h, config/mips/xm-linux.h: Ditto.
	* config/powerpc/tm-linux.h, config/s390/nm-linux.h: Ditto.
	* config/s390/tm-linux.h, config/sh/tm-linux.h: Ditto.
	* config/sparc/nm-linux.h, config/sparc/tm-linux.h: Ditto.
	* config/sparc/tm-sp64linux.h, config/sparc/xm-linux.h: Ditto.
	Fix PR gdb/378.
 	
Index: testsuite/ChangeLog
2002-02-24  Andrew Cagney  <ac131313@redhat.com>

	* testsuite/gdb.base/huge.c: Replace ``Linux'' with either
	``GNU/Linux'' or ``Linux kernel''
	* testsuite/gdb.threads/pthreads.c: Ditto.

Index: config/nm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/nm-linux.h,v
retrieving revision 1.11
diff -u -r1.11 nm-linux.h
--- nm-linux.h	2002/01/08 22:09:47	1.11
+++ nm-linux.h	2002/02/24 22:49:26
@@ -1,7 +1,7 @@
 /* Native support for GNU/Linux.
-   Copyright 1999, 2000, 2001
-   Free Software Foundation, Inc.
 
+   Copyright 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
    Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-/* Linux is SVR4-ish but its /proc file system isn't.  */
+/* GNU/Linux is SVR4-ish but its /proc file system isn't.  */
 #undef USE_PROC_FS
 
 /* Tell GDB that we can attach and detach other processes.  */
Index: config/alpha/nm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/alpha/nm-linux.h,v
retrieving revision 1.7
diff -u -r1.7 nm-linux.h
--- nm-linux.h	2001/10/14 20:42:07	1.7
+++ nm-linux.h	2002/02/24 22:49:29
@@ -1,7 +1,8 @@
-/* Native definitions for alpha running Linux.
-   Copyright 1993, 1994, 1996, 1998, 2000, 2001
-   Free Software Foundation, Inc.
+/* Native definitions for alpha running GNU/Linux.
 
+   Copyright 1993, 1994, 1996, 1998, 2000, 2001, 2002 Free Software
+   Foundation, Inc.
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -37,7 +38,7 @@
 
 #define U_REGS_OFFSET 0
 
-/* FIXME: This is probably true, or should be, on all Linux ports.
+/* FIXME: This is probably true, or should be, on all GNU/Linux ports.
    IA64?  Sparc64?  */
 #define PTRACE_ARG3_TYPE long
 
@@ -49,7 +50,7 @@
 
 #define CANNOT_STEP_BREAKPOINT
 
-/* Linux has shared libraries.  */
+/* GNU/Linux has shared libraries.  */
 
 #define GDB_TARGET_HAS_SHARED_LIBS
 
Index: config/alpha/tm-alpha.h
===================================================================
RCS file: /cvs/src/src/gdb/config/alpha/tm-alpha.h,v
retrieving revision 1.16
diff -u -r1.16 tm-alpha.h
--- tm-alpha.h	2002/01/29 04:42:34	1.16
+++ tm-alpha.h	2002/02/24 22:49:30
@@ -1,7 +1,8 @@
 /* Definitions to make GDB run on an Alpha box under OSF1.  This is
-   also used by the Alpha/Netware and Alpha/Linux targets.
-   Copyright 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2002
-   Free Software Foundation, Inc.
+   also used by the Alpha/Netware and Alpha GNU/Linux targets.
+
+   Copyright 1993, 1994, 1995, 1996, 1998, 1999, 2000, 2002 Free
+   Software Foundation, Inc.
 
    This file is part of GDB.
 
Index: config/alpha/xm-alphalinux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/alpha/xm-alphalinux.h,v
retrieving revision 1.4
diff -u -r1.4 xm-alphalinux.h
--- xm-alphalinux.h	2001/12/02 02:57:14	1.4
+++ xm-alphalinux.h	2002/02/24 22:49:30
@@ -1,5 +1,6 @@
-/* Host definitions for GDB running on an Alpha under Linux
-   Copyright 1996, 2001 Free Software Foundation, Inc.
+/* Host definitions for GDB running on an Alpha under GNU/Linux.
+
+   Copyright 1996, 2001, 2002 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
Index: config/i386/nm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/i386/nm-linux.h,v
retrieving revision 1.15
diff -u -r1.15 nm-linux.h
--- nm-linux.h	2001/10/14 20:42:07	1.15
+++ nm-linux.h	2002/02/24 22:49:30
@@ -1,7 +1,7 @@
-/* Native support for Linux/x86.
-   Copyright 1986, 1987, 1989, 1992, 1993, 1994, 1995, 1996, 1997, 1998,
-   1999, 2000, 2001
-   Free Software Foundation, Inc.
+/* Native support for GNU/Linux x86.
+
+   Copyright 1986, 1987, 1989, 1992, 1993, 1994, 1995, 1996, 1997,
+   1998, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
Index: config/i386/nm-x86-64.h
===================================================================
RCS file: /cvs/src/src/gdb/config/i386/nm-x86-64.h,v
retrieving revision 1.2
diff -u -r1.2 nm-x86-64.h
--- nm-x86-64.h	2002/01/20 09:29:41	1.2
+++ nm-x86-64.h	2002/02/24 22:49:31
@@ -1,6 +1,7 @@
-/* Native support for Linux/x86-64.
-   Copyright 2001, 2002  Free Software Foundation, Inc.
-   Contributed by Jiri Smid, SuSE Labs.
+/* Native support for GNU/Linux x86-64.
+
+   Copyright 2001, 2002 Free Software Foundation, Inc.  Contributed by
+   Jiri Smid, SuSE Labs.
 
    This file is part of GDB.
 
Index: config/i386/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/i386/tm-linux.h,v
retrieving revision 1.16
diff -u -r1.16 tm-linux.h
--- tm-linux.h	2001/11/08 00:03:52	1.16
+++ tm-linux.h	2002/02/24 22:49:31
@@ -1,7 +1,8 @@
 /* Definitions to target GDB to GNU/Linux on 386.
-   Copyright 1992, 1993, 1995, 1996, 1998, 1999, 2000, 2001
-   Free Software Foundation, Inc.
 
+   Copyright 1992, 1993, 1995, 1996, 1998, 1999, 2000, 2001, 2002 Free
+   Software Foundation, Inc.
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -60,7 +61,7 @@
 #define REGISTER_RAW_SIZE(reg) i386_linux_register_raw_size ((reg))
 extern int i386_linux_register_raw_size (int reg);
 
-/* Linux/ELF uses stabs-in-ELF with the DWARF register numbering
+/* GNU/Linux ELF uses stabs-in-ELF with the DWARF register numbering
    scheme by default, so we must redefine STAB_REG_TO_REGNUM.  This
    messes up the floating-point registers for a.out, but there is not
    much we can do about that.  */
Index: config/m68k/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/m68k/tm-linux.h,v
retrieving revision 1.5
diff -u -r1.5 tm-linux.h
--- tm-linux.h	2001/03/14 23:23:12	1.5
+++ tm-linux.h	2002/02/24 22:49:31
@@ -1,5 +1,7 @@
-/* Definitions to target GDB to Linux on m680x0
-   Copyright 1996, 1998, 1999, 2000 Free Software Foundation, Inc.
+/* Definitions to target GDB to GNU/Linux on m680x0.
+
+   Copyright 1996, 1998, 1999, 2000, 2002 Free Software Foundation,
+   Inc.
 
    This file is part of GDB.
 
Index: config/mips/nm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/mips/nm-linux.h,v
retrieving revision 1.2
diff -u -r1.2 nm-linux.h
--- nm-linux.h	2001/10/14 20:42:07	1.2
+++ nm-linux.h	2002/02/24 22:49:31
@@ -1,5 +1,6 @@
-/* Native-dependent definitions for Linux/MIPS.
-   Copyright 1996, 2001 Free Software Foundation, Inc.
+/* Native-dependent definitions for GNU/Linux on MIPS.
+
+   Copyright 1996, 2001, 2002 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
Index: config/mips/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/mips/tm-linux.h,v
retrieving revision 1.2
diff -u -r1.2 tm-linux.h
--- tm-linux.h	2001/07/11 21:49:41	1.2
+++ tm-linux.h	2002/02/24 22:49:31
@@ -1,6 +1,7 @@
-/* Target-dependent definitions for Linux/MIPS.
-   Copyright 2001 Free Software Foundation, Inc.
+/* Target-dependent definitions for GNU/Linux MIPS.
 
+   Copyright 2001, 2002 Free Software Foundation, Inc.
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -30,7 +31,7 @@
 #undef SKIP_TRAMPOLINE_CODE
 #undef IGNORE_HELPER_CALL
 
-/* Linux/MIPS has __SIGRTMAX == 127.  */
+/* GNU/Linux MIPS has __SIGRTMAX == 127.  */
 
 #define REALTIME_LO 32
 #define REALTIME_HI 128
Index: config/mips/xm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/mips/xm-linux.h,v
retrieving revision 1.3
diff -u -r1.3 xm-linux.h
--- xm-linux.h	2001/12/02 02:57:16	1.3
+++ xm-linux.h	2002/02/24 22:49:31
@@ -1,5 +1,6 @@
-/* Host definitions for Linux/MIPS.
-   Copyright 2001 Free Software Foundation, Inc.
+/* Host definitions for GNU/Linux on MIPS.
+
+   Copyright 2001, 2002 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
Index: config/powerpc/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/powerpc/tm-linux.h,v
retrieving revision 1.9
diff -u -r1.9 tm-linux.h
--- tm-linux.h	2001/03/20 18:16:20	1.9
+++ tm-linux.h	2002/02/24 22:49:31
@@ -1,5 +1,6 @@
-/* Definitions to target GDB to Linux on 386.
-   Copyright 1992, 1993, 2000 Free Software Foundation, Inc.
+/* Definitions to target GDB to GNU/Linux on PowerPC.
+
+   Copyright 1992, 1993, 2000, 2002 Free Software Foundation, Inc.
 
 This file is part of GDB.
 
Index: config/s390/nm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/s390/nm-linux.h,v
retrieving revision 1.4
diff -u -r1.4 nm-linux.h
--- nm-linux.h	2001/12/06 16:17:06	1.4
+++ nm-linux.h	2002/02/24 22:49:31
@@ -1,7 +1,10 @@
-/* Native support for Linux for S390
-   Copyright 2001 Free Software Foundation, Inc.
-   Ported by D.J. Barrow for IBM Deutschland Entwicklung GmbH, IBM Corporation.
-   derived from i390-nmlinux.h
+/* Native support for GNU/Linux on S390.
+
+   Copyright 2001, 2002 Free Software Foundation, Inc.
+
+   Ported by D.J. Barrow for IBM Deutschland Entwicklung GmbH, IBM
+   Corporation.  derived from i390-nmlinux.h
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
Index: config/s390/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/s390/tm-linux.h,v
retrieving revision 1.2
diff -u -r1.2 tm-linux.h
--- tm-linux.h	2001/10/13 22:13:35	1.2
+++ tm-linux.h	2002/02/24 22:49:31
@@ -1,5 +1,7 @@
-/* Target definitions for GDB for a s390 running Linux.
-   Copyright 2001 Free Software Foundation, Inc.
+/* Target definitions for GDB for a s390 running GNU/Linux.
+
+   Copyright 2001, 2002 Free Software Foundation, Inc.
+
    Contributed by D.J. Barrow (djbarrow@de.ibm.com,barrow_dj@yahoo.com)
    for IBM Deutschland Entwicklung GmbH, IBM Corporation.
 
Index: config/sh/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/sh/tm-linux.h,v
retrieving revision 1.2
diff -u -r1.2 tm-linux.h
--- tm-linux.h	2001/03/06 08:21:35	1.2
+++ tm-linux.h	2002/02/24 22:49:31
@@ -1,6 +1,8 @@
-/* Target-specific definitions for Linux running on a Hitachi Super-H.
-   Copyright 2000 Free Software Foundation, Inc.
+/* Target-specific definitions for GNU/Linux running on a Hitachi
+   Super-H.
 
+   Copyright 2000, 2002 Free Software Foundation, Inc.
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -18,7 +20,7 @@
    Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-/* Pull in Linux generic defs */
+/* Pull in GNU/Linux generic defs.  */
 #include "tm-linux.h"
 
 /* Pull in sh-target defs */
Index: config/sparc/nm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/sparc/nm-linux.h,v
retrieving revision 1.4
diff -u -r1.4 nm-linux.h
--- nm-linux.h	2001/03/06 08:21:36	1.4
+++ nm-linux.h	2002/02/24 22:49:31
@@ -1,6 +1,7 @@
-/* Macro definitions for running gdb on a Sparc running Linux.
-   Copyright 1989, 1992, 1996, 1998, 1999, 2000
-   Free Software Foundation, Inc.
+/* Macro definitions for running gdb on a Sparc running GNU/Linux.
+
+   Copyright 1989, 1992, 1996, 1998, 1999, 2000, 2002 Free Software
+   Foundation, Inc.
 
    This file is part of GDB.
 
Index: config/sparc/tm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/sparc/tm-linux.h,v
retrieving revision 1.2
diff -u -r1.2 tm-linux.h
--- tm-linux.h	2001/03/06 08:21:37	1.2
+++ tm-linux.h	2002/02/24 22:49:31
@@ -1,6 +1,7 @@
-/* Macro definitions for GDB for a Sparc running Linux.
-   Copyright 1989, 1992, 1994, 1995, 1998, 1999
-   Free Software Foundation, Inc.
+/* Macro definitions for GDB for a Sparc running GNU/Linux.
+
+   Copyright 1989, 1992, 1994, 1995, 1998, 1999, 2002 Free Software
+   Foundation, Inc.
 
    This file is part of GDB.
 
Index: config/sparc/tm-sp64linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/sparc/tm-sp64linux.h,v
retrieving revision 1.1
diff -u -r1.1 tm-sp64linux.h
--- tm-sp64linux.h	2001/02/27 17:04:47	1.1
+++ tm-sp64linux.h	2002/02/24 22:49:31
@@ -1,5 +1,6 @@
-/* Macro definitions for GDB for a UltraSparc running Linux.
-   Copyright 2001 Free Software Foundation, Inc.
+/* Macro definitions for GDB for a UltraSparc running GNU/Linux.
+
+   Copyright 2001, 2002 Free Software Foundation, Inc.
 
 This file is part of GDB.
 
Index: config/sparc/xm-linux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/sparc/xm-linux.h,v
retrieving revision 1.5
diff -u -r1.5 xm-linux.h
--- xm-linux.h	2002/01/20 01:12:51	1.5
+++ xm-linux.h	2002/02/24 22:49:34
@@ -1,6 +1,7 @@
-/* Macro definitions for running gdb on a Sparc running Linux.
-   Copyright 1989, 1993, 1994, 1995, 1996, 1998, 2001
-   Free Software Foundation, Inc.
+/* Macro definitions for running gdb on a Sparc running GNU/Linux.
+
+   Copyright 1989, 1993, 1994, 1995, 1996, 1998, 2001, 2002 Free
+   Software Foundation, Inc.
 
    This file is part of GDB.
 
Index: testsuite/gdb.base/huge.c
===================================================================
RCS file: /cvs/src/src/gdb/testsuite/gdb.base/huge.c,v
retrieving revision 1.1
diff -u -r1.1 huge.c
--- huge.c	2002/01/08 01:00:09	1.1
+++ huge.c	2002/02/24 22:50:10
@@ -2,11 +2,9 @@
  * Test GDB's ability to read a very large data object from target memory.
  */
 
-/* 
- * A value that will produce a target data object 
- * large enough to crash GDB.  0x200000 is big enough
- * on Linux, other systems may need a larger number.
- */
+/* A value that will produce a target data object large enough to
+   crash GDB.  0x200000 is big enough on GNU/Linux, other systems may
+   need a larger number.  */
 
 #define CRASH_GDB 0x200000
 
Index: testsuite/gdb.threads/pthreads.c
===================================================================
RCS file: /cvs/src/src/gdb/testsuite/gdb.threads/pthreads.c,v
retrieving revision 1.2
diff -u -r1.2 pthreads.c
--- pthreads.c	2002/02/24 20:37:56	1.2
+++ pthreads.c	2002/02/24 22:50:13
@@ -17,7 +17,8 @@
    should issue an ERROR result.. */
 
 #ifdef __linux__
-#define  _MIT_POSIX_THREADS 1	/* Linux (or at least RedHat 4.0) needs this */
+#define  _MIT_POSIX_THREADS 1	/* GNU/Linux (or at least RedHat 4.0)
+                                   needs this */
 #endif
 
 #include <pthread.h>

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: config/alpha/tm-alphalinux.h
===================================================================
RCS file: /cvs/src/src/gdb/config/alpha/tm-alphalinux.h,v
retrieving revision 1.3
diff -u -r1.3 tm-alphalinux.h
--- tm-alphalinux.h	2001/03/06 08:21:21	1.3
+++ tm-alphalinux.h	2002/02/24 22:49:30
@@ -1,7 +1,10 @@
-/* Definitions to make GDB run on an Alpha box under Linux.  The
-   definitions here are used when the _target_ system is running Linux.
-   Copyright 1996, 1998, 1999, 2000 Free Software Foundation, Inc.
+/* Definitions to make GDB run on an Alpha box under GNU/Linux.  The
+   definitions here are used when the _target_ system is running
+   GNU/Linux.
 
+   Copyright 1996, 1998, 1999, 2000, 2002 Free Software Foundation,
+   Inc.
+
    This file is part of GDB.
 
    This program is free software; you can redistribute it and/or modify
@@ -38,7 +41,7 @@
 
 /* Number of traps that happen between exec'ing the shell to run an
    inferior, and when we finally get to the inferior code.  This is 2
-   on Linux and most implementations.  */
+   on GNU/Linux and most implementations.  */
 
 #undef START_INFERIOR_TRAPS_EXPECTED
 #define START_INFERIOR_TRAPS_EXPECTED 2
@@ -69,8 +72,8 @@
 
 /* If FRAME refers to a sigtramp frame, return the address of the next frame.
 
-   Under Linux, sigtramp handlers have dynamically generated procedure
-   descriptors that make this hack unnecessary.  */
+   Under GNU/Linux, sigtramp handlers have dynamically generated
+   procedure descriptors that make this hack unnecessary.  */
 
 #undef FRAME_PAST_SIGTRAMP_FRAME
 #define FRAME_PAST_SIGTRAMP_FRAME(frame, pc)	(0)